Primeros pasos — titulo...

# Primeros pasos

Veamos algunos conceptos de esta herramienta para comenzar.

A la izquierda vas a poder ver un editor para escribir programas. Ahí puedes ir colocando todo el código de tu programa.

Por ejemplo, lo que sigue es un ejemplo de código listo para usar:

    mi_nombre = "Pepe"
    print("Hola " + mi_nombre)

Probemos el ejemplo, has `click` sobre el código que aparece mas arriba. Cuando hagas `click`, el código se va a trasladar inmediatamente al editor que está a la izquierda.

## Ejecutando

Para poner en funcionamiento nuestro programa, solo tenemos que hacer click en el botón que dice “ejecutar” arriba del editor.

Una vez que hagas click, la ventana del editor se va a modificar. ¡ y aparece un mensaje de saludo !.

Este modo se llama modo interactivo, ahí podemos ver el resultado de nuestro programa y además, podemos seguir escribiendo código de prueba.

Por ejemplo, podrías escribir `2 + 4` o `print(mi_nombre)`. Cada cosa que escribas se va a ejecutar inmediatamente.

## Volviendo al editor

Para volver al editor simplemente tenemos que pulsar el botón `terminar`.

## Resumiendo

Esto es todo lo que necesitamos saber para comenzar a usar `Patín`:

> - Se puede hacer click sobre el código de la documentación.
> - El botón ejecutar nos muestra el resultado del programa y pasa a modo interactivo.
> - Si pulsamos el botón terminar volvemos al editor.

A partir de aquí, te recomiendo ir viendo este tutorial paso a paso, y cada vez que quieras inspeccionar o investigar hacelo, la programación de computadoras es mas práctica de lo que parece...